#
# spec file for package popeye
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define __arch_install_post export NO_BRP_STRIP_DEBUG=true

Name:           popeye
Version:        0.11.1
Release:        1.6
Summary:        A Kubernetes cluster resource sanitizer
License:        Apache-2.0
URL:            https://github.com/derailed/popeye
Source:         popeye-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  go >= 1.17

%description
Pluto is a utility to help users find deprecated Kubernetes apiVersions in their code repositories and their helm releases.
peye is a utility that scans live Kubernetes cluster and reports potential issues with deployed resources and configurations. It sanitizes your cluster based on what's deployed and not what's sitting on disk. By scanning your cluster, it detects misconfigurations and helps you to ensure that best practices are in place, thus preventing future headaches. It aims at reducing the cognitive overload one faces when operating a Kubernetes cluster in the wild. Furthermore, if your cluster employs a metric-server, it reports potential resources over/under allocations and attempts to warn you should your cluster run out of capacity.
Popeye is a readonly tool, it does not alter any of your Kubernetes resources in any way!

%prep
%setup -q
%setup -q -T -D -a 1

%build
go build \
   -mod=vendor \
   -ldflags="-X main.Version=%{version}"

%install
# Install the binary.
install -D -m 0755 %{name} "%{buildroot}/%{_bindir}/%{name}"

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%changelog
* Tue Feb 21 2023 kastl@b1-systems.de
- Update to version 0.11.1:
  * fix #245
  * deprecated cronjob api
* Mon Feb 13 2023 kastl@b1-systems.de
- Update to version 0.11.0:
  * Release v0.11.0
  * Add check for pods that are managed by multiple pdbs
  * Update README.md
  * invalid value for --force-exit-zero
  * add a non-root user in docker image
  * optimize README documents
  * 📦 Add arm64 Darwin releases to krew-index
  * Add go install option to readme
  * Fixing CVE issue for client_golang 1.11.0 to 1.12.2
  * Fixing CVE issue for client_golang 1.11.0 to 1.12.1. Reverting from 1.12.2
  * Fixing CVE issue for client_golang 1.11.0 to 1.12.2
  * Add check for pods that are managed by multiple pdbs
  * fix RBAC rules in README.md
* Tue Jun 28 2022 kastl@b1-systems.de
- Update to version 0.10.1:
  * fix issue with 2x pdb
  * fix docker build
* Thu Apr 14 2022 kastl@b1-systems.de
- Update to version 0.10.0:
  * update rel notes
  * update docs
  * fix: remove useless if/then
  * bump k8s version
  * fix: s3-endpoint flag description
  * Fix HPA API version derailed#207
  * feat: add other S3 object storage compatible support
  * feat: add GitPod for better UX for contributors
  * Fixes #211 (but might break backward compatilbility)
  * Update codes.md
  * Update codes.yml
  * Sets default registry as a constant. Only sanitizes registries if a registry list is provided.
  * Adds rule 113 which makes possible to add a list of allowed registries to pull images from. Otherwise, all images are allowed.
- BuildRequire go1.17
* Wed Jan  5 2022 kastl@b1-systems.de
- Update to version 0.9.8:
  * NOTE: Fix'n brew deprecation warnings
* Wed Jan  5 2022 kastl@b1-systems.de
- Update to version 0.9.7:
  * Issue #190 Popeye docker image tag 0.9.6 not available on quay.io
  * Issue #163 popeye 0.9.0 with K8S 1.21.0 bug on PodDisruptionBudget - Wrong default API. With Feelings!
* Wed Jan  5 2022 kastl@b1-systems.de
- Update to version 0.9.6:
  * Issue #188 Can't run Popeye: No resource meta found for networking.k8s.io/v1/ingresses. With Feelings!
  * Issue #178 Custom handling of client-go/rest warnings. Sending to logger instead
* Wed Jan  5 2022 kastl@b1-systems.de
- Update to version 0.9.5:
  * Issue #163 popeye 0.9.0 with K8S 1.21.0 bug on PodDisruptionBudget - Wrong default API - With Feelings!
* Wed Jan  5 2022 kastl@b1-systems.de
- Update to version 0.9.4:
  * Issue #163 popeye 0.9.0 with K8S 1.21.0 bug on PodDisruptionBudget - Wrong default API
  * Issue #712 [POP-712] Found only one master node not flag on the right node
  * Issue #181 [POP-404] Deprecation check failed
* Wed Jan  5 2022 kastl@b1-systems.de
- Update to version 0.9.3:
  * Issue #170 Can't run popeye when kubernetes has networking.k8s.io/v1/ingresses
  * PR #1102 Load codes with embed:fs and fix code 1102 format. Big Thanks to GoodWine for this excellent PR!!
* Wed May 26 2021 Johannes Kastl <kastl@b1-systems.de>
- initial version of package popeye
